/**
* @license Apache-2.0
*
* Copyright (c) 2020 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var tape = require( 'tape' );
var proxyquire = require( 'proxyquire' );
var isObject = require( '@stdlib/assert/is-plain-object' );
var IS_BROWSER = require( '@stdlib/assert/is-browser' );
var db = require( './../lib/browser_db.js' );
var getFile = require( './../lib/browser_get_file.js' );


// TESTS //

tape( 'main export is a function', function test( t ) {
	t.ok( true, __filename );
	t.equal( typeof getFile, 'function', 'main export is a function' );
	t.end();
});

tape( 'the function returns an object', function test( t ) {
	var fcn;

	// NOTE: when bundled for browsers, we expect that the Node.js database implementation has been swapped for a browser database; consequently, when testing on Node, we need to perform a similar swap...
	if ( IS_BROWSER ) {
		fcn = getFile;
	} else {
		fcn = proxyquire( './../lib/browser_get_file.js', {
			'./db.js': db
		});
	}
	t.equal( isObject( fcn( 0 ) ), true, 'returns an object' );
	t.end();
});
