/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

var rose = require( './../lib' );

var scalar;
var data;
var d;
var i;

data = rose();

// As done by Nightingale, calculate the average annual mortality per 1000 for each cause. See http://understandinguncertainty.org/node/214.
for ( i = 0; i < data.length; i++ ) {
	d = data[ i ];
	scalar = 1000.0 * 12.0 / d.army_size;
	d.disease *= scalar;
	d.wounds *= scalar;
	d.other *= scalar;
}
console.dir( data );
