/**
* @license Apache-2.0
*
* Copyright (c) 2021 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

// This file is generated using `scripts/build.js`.

'use strict';

// MAIN //

var files = [
	'1790_george_washington_n.json',
	'1791_george_washington_n.json',
	'1792_george_washington_n.json',
	'1793_george_washington_n.json',
	'1794_george_washington_n.json',
	'1795_george_washington_n.json',
	'1796_george_washington_n.json',
	'1797_john_adams_f.json',
	'1798_john_adams_f.json',
	'1799_john_adams_f.json',
	'1800_john_adams_f.json',
	'1801_thomas_jefferson_dr.json',
	'1802_thomas_jefferson_dr.json',
	'1803_thomas_jefferson_dr.json',
	'1804_thomas_jefferson_dr.json',
	'1805_thomas_jefferson_dr.json',
	'1806_thomas_jefferson_dr.json',
	'1807_thomas_jefferson_dr.json',
	'1808_thomas_jefferson_dr.json',
	'1809_james_madison_dr.json',
	'1810_james_madison_dr.json',
	'1811_james_madison_dr.json',
	'1812_james_madison_dr.json',
	'1813_james_madison_dr.json',
	'1814_james_madison_dr.json',
	'1815_james_madison_dr.json',
	'1816_james_madison_dr.json',
	'1817_james_monroe_dr.json',
	'1818_james_monroe_dr.json',
	'1819_james_monroe_dr.json',
	'1820_james_monroe_dr.json',
	'1821_james_monroe_dr.json',
	'1822_james_monroe_dr.json',
	'1823_james_monroe_dr.json',
	'1824_james_monroe_dr.json',
	'1825_john_quincy_adams_dr.json',
	'1826_john_quincy_adams_dr.json',
	'1827_john_quincy_adams_dr.json',
	'1828_john_quincy_adams_dr.json',
	'1829_andrew_jackson_d.json',
	'1830_andrew_jackson_d.json',
	'1831_andrew_jackson_d.json',
	'1832_andrew_jackson_d.json',
	'1833_andrew_jackson_d.json',
	'1834_andrew_jackson_d.json',
	'1835_andrew_jackson_d.json',
	'1836_andrew_jackson_d.json',
	'1837_martin_van_buren_d.json',
	'1838_martin_van_buren_d.json',
	'1839_martin_van_buren_d.json',
	'1840_martin_van_buren_d.json',
	'1841_john_tyler_wd.json',
	'1842_john_tyler_wd.json',
	'1843_john_tyler_wd.json',
	'1844_john_tyler_wd.json',
	'1845_james_polk_d.json',
	'1846_james_polk_d.json',
	'1847_james_polk_d.json',
	'1848_james_polk_d.json',
	'1849_zachary_taylor_w.json',
	'1850_millard_fillmore_w.json',
	'1851_millard_fillmore_w.json',
	'1852_millard_fillmore_w.json',
	'1853_franklin_pierce_d.json',
	'1854_franklin_pierce_d.json',
	'1855_franklin_pierce_d.json',
	'1856_franklin_pierce_d.json',
	'1857_james_buchanan_d.json',
	'1858_james_buchanan_d.json',
	'1859_james_buchanan_d.json',
	'1860_james_buchanan_d.json',
	'1861_abraham_lincoln_r.json',
	'1862_abraham_lincoln_r.json',
	'1863_abraham_lincoln_r.json',
	'1864_abraham_lincoln_r.json',
	'1865_andrew_johnson_nu.json',
	'1866_andrew_johnson_nu.json',
	'1867_andrew_johnson_nu.json',
	'1868_andrew_johnson_nu.json',
	'1869_ulysses_s_grant_r.json',
	'1870_ulysses_s_grant_r.json',
	'1871_ulysses_s_grant_r.json',
	'1872_ulysses_s_grant_r.json',
	'1873_ulysses_s_grant_r.json',
	'1874_ulysses_s_grant_r.json',
	'1875_ulysses_s_grant_r.json',
	'1876_ulysses_s_grant_r.json',
	'1877_rutherford_b_hayes_r.json',
	'1878_rutherford_b_hayes_r.json',
	'1879_rutherford_b_hayes_r.json',
	'1880_rutherford_b_hayes_r.json',
	'1881_chester_a_arthur_r.json',
	'1882_chester_a_arthur_r.json',
	'1883_chester_a_arthur_r.json',
	'1884_chester_a_arthur_r.json',
	'1885_grover_cleveland_d.json',
	'1886_grover_cleveland_d.json',
	'1887_grover_cleveland_d.json',
	'1888_grover_cleveland_d.json',
	'1889_benjamin_harrison_r.json',
	'1890_benjamin_harrison_r.json',
	'1891_benjamin_harrison_r.json',
	'1892_benjamin_harrison_r.json',
	'1893_grover_cleveland_d.json',
	'1894_grover_cleveland_d.json',
	'1895_grover_cleveland_d.json',
	'1896_grover_cleveland_d.json',
	'1897_william_mc_kinley_r.json',
	'1898_william_mc_kinley_r.json',
	'1899_william_mc_kinley_r.json',
	'1900_william_mc_kinley_r.json',
	'1901_theodore_roosevelt_r.json',
	'1902_theodore_roosevelt_r.json',
	'1903_theodore_roosevelt_r.json',
	'1904_theodore_roosevelt_r.json',
	'1905_theodore_roosevelt_r.json',
	'1906_theodore_roosevelt_r.json',
	'1907_theodore_roosevelt_r.json',
	'1908_theodore_roosevelt_r.json',
	'1909_william_h_taft_r.json',
	'1910_william_h_taft_r.json',
	'1911_william_h_taft_r.json',
	'1912_william_h_taft_r.json',
	'1913_woodrow_wilson_d.json',
	'1914_woodrow_wilson_d.json',
	'1915_woodrow_wilson_d.json',
	'1916_woodrow_wilson_d.json',
	'1917_woodrow_wilson_d.json',
	'1918_woodrow_wilson_d.json',
	'1919_woodrow_wilson_d.json',
	'1920_woodrow_wilson_d.json',
	'1921_warren_g_harding_r.json',
	'1922_warren_g_harding_r.json',
	'1923_calvin_coolidge_r.json',
	'1924_calvin_coolidge_r.json',
	'1925_calvin_coolidge_r.json',
	'1926_calvin_coolidge_r.json',
	'1927_calvin_coolidge_r.json',
	'1928_calvin_coolidge_r.json',
	'1929_herbert_hoover_r.json',
	'1930_herbert_hoover_r.json',
	'1931_herbert_hoover_r.json',
	'1932_herbert_hoover_r.json',
	'1934_franklin_d_roosevelt_d.json',
	'1935_franklin_d_roosevelt_d.json',
	'1936_franklin_d_roosevelt_d.json',
	'1937_franklin_d_roosevelt_d.json',
	'1938_franklin_d_roosevelt_d.json',
	'1939_franklin_d_roosevelt_d.json',
	'1940_franklin_d_roosevelt_d.json',
	'1941_franklin_d_roosevelt_d.json',
	'1942_franklin_d_roosevelt_d.json',
	'1943_franklin_d_roosevelt_d.json',
	'1944_franklin_d_roosevelt_d.json',
	'1945_franklin_d_roosevelt_d.json',
	'1946_harry_s_truman_d.json',
	'1947_harry_s_truman_d.json',
	'1948_harry_s_truman_d.json',
	'1949_harry_s_truman_d.json',
	'1950_harry_s_truman_d.json',
	'1951_harry_s_truman_d.json',
	'1952_harry_s_truman_d.json',
	'1953_dwight_d_eisenhower_r.json',
	'1953_harry_s_truman_d.json',
	'1954_dwight_d_eisenhower_r.json',
	'1955_dwight_d_eisenhower_r.json',
	'1956_dwight_d_eisenhower_r.json',
	'1957_dwight_d_eisenhower_r.json',
	'1958_dwight_d_eisenhower_r.json',
	'1959_dwight_d_eisenhower_r.json',
	'1960_dwight_d_eisenhower_r.json',
	'1961_dwight_d_eisenhower_r.json',
	'1961_john_f_kennedy_d.json',
	'1962_john_f_kennedy_d.json',
	'1963_john_f_kennedy_d.json',
	'1964_lyndon_b_johnson_d.json',
	'1965_lyndon_b_johnson_d.json',
	'1966_lyndon_b_johnson_d.json',
	'1967_lyndon_b_johnson_d.json',
	'1968_lyndon_b_johnson_d.json',
	'1969_lyndon_b_johnson_d.json',
	'1970_richard_nixon_r.json',
	'1971_richard_nixon_r.json',
	'1972_richard_nixon_r.json',
	'1973_richard_nixon_r.json',
	'1974_richard_nixon_r.json',
	'1975_gerald_r_ford_r.json',
	'1976_gerald_r_ford_r.json',
	'1977_gerald_r_ford_r.json',
	'1978_jimmy_carter_d.json',
	'1979_jimmy_carter_d.json',
	'1980_jimmy_carter_d.json',
	'1981_jimmy_carter_d.json',
	'1982_ronald_reagan_r.json',
	'1983_ronald_reagan_r.json',
	'1984_ronald_reagan_r.json',
	'1985_ronald_reagan_r.json',
	'1986_ronald_reagan_r.json',
	'1987_ronald_reagan_r.json',
	'1988_ronald_reagan_r.json',
	'1989_george_bush_r.json',
	'1990_george_bush_r.json',
	'1991_george_bush_r.json',
	'1992_george_bush_r.json',
	'1993_william_j_clinton_d.json',
	'1994_william_j_clinton_d.json',
	'1995_william_j_clinton_d.json',
	'1996_william_j_clinton_d.json',
	'1997_william_j_clinton_d.json',
	'1998_william_j_clinton_d.json',
	'1999_william_j_clinton_d.json',
	'2000_william_j_clinton_d.json',
	'2001_george_w_bush_r.json',
	'2002_george_w_bush_r.json',
	'2003_george_w_bush_r.json',
	'2004_george_w_bush_r.json',
	'2005_george_w_bush_r.json',
	'2006_george_w_bush_r.json',
	'2007_george_w_bush_r.json',
	'2008_george_w_bush_r.json',
	'2009_barack_obama_d.json',
	'2010_barack_obama_d.json',
	'2011_barack_obama_d.json',
	'2012_barack_obama_d.json',
	'2013_barack_obama_d.json',
	'2014_barack_obama_d.json',
	'2015_barack_obama_d.json',
	'2016_barack_obama_d.json',
	'2017_donald_j_trump_r.json',
	'2018_donald_j_trump_r.json',
	'2019_donald_j_trump_r.json',
	'2020_donald_j_trump_r.json',
	'2021_joseph_r_biden_d.json'
];


// EXPORTS //

module.exports = files;
