/*
* @license Apache-2.0
*
* Copyright (c) 2020 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

// TypeScript Version: 2.0

/**
* Returns a list of positive opinion words.
*
* ## Notes
*
* -   A word's appearance in a sentence does *not* necessarily imply a positive or negative opinion.
* -   The list includes misspelled words. Their presence is intentional, as such misspellings frequently occur in social media content.
* -   This function synchronously reads data from disk for each invocation. Such behavior is intentional and so is the avoidance of `require`. We assume that invocations are infrequent, and we want to avoid the `require` cache. This means that we allow data to be garbage collected and a user is responsible for explicitly caching data.
*
*
* @throws unable to read data
* @returns words
*
* @example
* var list = words();
* // returns [ 'a+', 'abound', 'abounds', 'abundance', ... ]
*/
declare function words(): Array<string>;


// EXPORTS //

export = words;
